@@ -136,6 +136,10 @@ def parse_args():
         '-a', '--service-account-email', required=True,
         help='Service Account email',
     )
+    parser_token.add_argument(
+        '-t', '--token-type', type=TokenType.from_str(TokenType), choices=list(TokenType),
+        help='Token type', default=TokenType.ACCESS,
+    )
     parser_token.add_argument(
         '-d', '--audience',
         help='Audience for ID token',
@@ -148,10 +152,6 @@ def parse_args():
         '-l', '--token-lifetime', type=int, default=DEFAULT_LIFETIME,
         help='Token lifetime, in seconds',
     )
-    parser_token.add_argument(
-        '-t', '--token-type', type=TokenType.from_str(TokenType), choices=list(TokenType),
-        help='Token type, in seconds', default=TokenType.ACCESS,
-    )
     parser_token.add_argument(
         '-m', '--prompt-management-key', action='store_true',
         help='Prompt for management key',
@@ -174,17 +174,17 @@ def parse_args():
         '-l', '--token-lifetime', type=int, default=DEFAULT_LIFETIME,
         help='Token lifetime, in seconds',
     )
-    parser_serve.add_argument(
-        '-m', '--prompt-management-key', action='store_true',
-        help='Prompt for management key',
-    )
     parser_serve.add_argument(
         '-c', '--cache-lifetime', type=int, default=CachedItem.DEFAULT_LIFETIME_SEC,
         help='Token/PIN cache lifetime, in seconds',
     )
+    parser_serve.add_argument(
+        '-m', '--prompt-management-key', action='store_true',
+        help='Prompt for management key',
+    )
     parser_serve.add_argument(
         '-v', '--verbosity', type=Verbosity.from_str(Verbosity), choices=list(Verbosity),
-        help='Prompt for management key', default=Verbosity.INFO,
+        help='Log verbosity level', default=Verbosity.INFO,
     )
 
     return parser.parse_args()
